OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} a modifié votre mot de passe",
    "You changed your password" : "Vous avez modifié votre mot de passe",
    "Your password was reset by an administrator" : "Votre mot de passe a été réinitialisé par un administrateur",
    "{actor} changed your email address" : "{actor} a modifié votre adresse e-mail",
    "You changed your email address" : "Vous avez modifié votre adresse e-mail",
    "Your email address was changed by an administrator" : "Votre adresse e-mail a été modifiée par un administrateur",
    "Security" : "Sécurité",
    "You successfully logged in using two-factor authentication (%1$s)" : "Vous avez réussi à vous connecter en utilisant l'authentification à deux facteurs (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Une tentative de connexion utilisant l'authentification à deux facteurs a échoué (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Votre <strong>mot de passe</strong> ou <strong>adresse e-mail</strong> a été modifié",
    "Your apps" : "Vos applications",
    "Updates" : "Mises à jour",
    "Enabled apps" : "Applications activées",
    "Disabled apps" : "Applications désactivées",
    "App bundles" : "Pack d'applications",
    "Wrong password" : "Mot de passe incorrect",
    "Saved" : "Sauvegardé",
    "No user supplied" : "Aucun utilisateur fourni",
    "Unable to change password" : "Impossible de modifier le mot de passe",
    "Authentication error" : "Erreur d'authentification",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données de l'utilisateur seront perdues",
    "Wrong admin recovery password. Please check the password and try again." : "Mot de passe administrateur de récupération de données non valable. Veuillez vérifier le mot de passe et essayer à nouveau.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "L'infrastructure d'arrière-plan ne supporte pas la modification de mot de passe, mais la clef de chiffrement de l'utilisateur a été mise à jour.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "le partage Federated Cloud ou l'installation et la mise à jour d'applications par l'app store",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL utilise %s %s, qui est une version obsolète. Veuillez mettre à jour votre système d'exploitation, ou des fonctionnalités telles que %s ne fonctionneront pas correctement.",
    "Group already exists." : "Ce groupe existe déjà.",
    "Unable to add group." : "Impossible d'ajouter le groupe.",
    "Unable to delete group." : "Impossible de supprimer le groupe.",
    "Invalid SMTP password." : "Mot de passe SMTP incorrect.",
    "Email setting test" : "Test des paramètres e-mail",
    "Well done, %s!" : "Bien joué, %s !",
    "If you received this email, the email configuration seems to be correct." : "Si vous avez reçu cet e-mail, la configuration de l'adresse e-mail semble être correcte.",
    "Email could not be sent. Check your mail server log" : "L'email n'a pu être envoyé. Vérifiez le journal du serveur de messagerie",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres. (Erreur: %s)",
    "You need to set your user email before being able to send test emails." : "Vous devez définir une adresse e-mail dans vos paramètres personnels avant de pouvoir envoyer des e-mails de test.",
    "Invalid mail address" : "Adresse e-mail non valide",
    "No valid group selected" : "Aucun groupe valide sélectionné",
    "A user with that name already exists." : "Un utilisateur à ce nom existe déjà.",
    "To send a password link to the user an email address is required." : "Pour envoyer un mot de passe par lien à l'utilisateur, une adresse mail est requise.",
    "Unable to create user." : "Impossible de créer l'utilisateur.",
    "Unable to delete user." : "Impossible de supprimer l'utilisateur.",
    "Error while enabling user." : "Erreur lors de l'activation de l'utilisateur.",
    "Error while disabling user." : "Erreur lors de la désactivation de l'utilisateur.",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pour vérifier votre compte Twitter, postez le tweet suivant sur Twitter (veuillez vérifier de le poster sans saut de ligne) :",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pour vérifier votre site web, placez le contenu suivant à la racine de votre site à '.well-known/CloudIdVerificationCode.txt' (veuillez vérifier que le texte complet est en une seule ligne) :",
    "Settings saved" : "Paramètres sauvegardés",
    "Unable to change full name" : "Impossible de modifier le nom complet",
    "Unable to change email address" : "Impossible de modifier l'adresse e-mail",
    "Your full name has been changed." : "Votre nom complet a été modifié.",
    "Forbidden" : "Interdit",
    "Invalid user" : "Utilisateur non valable",
    "Unable to change mail address" : "Impossible de modifier l'adresse e-mail",
    "Email saved" : "E-mail sauvegardé",
    "%1$s changed your password on %2$s." : "%1$s a modifié votre mot de passe sur %2$s.",
    "Your password on %s was changed." : "Votre mot de passe sur %s a été modifié.",
    "Your password on %s was reset by an administrator." : "Votre mot de passe sur %s a été réinitialisé par un administrateur.",
    "Password for %1$s changed on %2$s" : "Mot de passe pour %1$s a été modifié sur %2$s",
    "Password changed for %s" : "Mot de passe modifié pour %s",
    "If you did not request this, please contact an administrator." : "Si vous n'aviez pas effectué cette demande, veuillez contacter un administrateur.",
    "%1$s changed your email address on %2$s." : "%1$s a modifié votre adresse e-mail sur %2$s.",
    "Your email address on %s was changed." : "Votre adresse e-mail sur %s a été modifié.",
    "Your email address on %s was changed by an administrator." : "Votre adresse e-mail sur %s a été modifié par un administrateur.",
    "Email address for %1$s changed on %2$s" : "Adresse e-mail pour %1$s a été modifié sur %2$s",
    "Email address changed for %s" : "Adresse e-mail a été modifié pour %s",
    "The new email address is %s" : "La nouvelle adresse e-mail est %s",
    "Your %s account was created" : "Votre compte %s a été créé",
    "Welcome aboard" : "Bienvenue à bord",
    "Welcome aboard %s" : "Bienvenue à bord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenue dans votre compte %s, vous pouvez ajouter, protéger et partager vos données.",
    "Your username is: %s" : "Votre nom d'utilisateur est : %s",
    "Set your password" : "Saisissez votre mot de passe",
    "Go to %s" : "Aller à %s",
    "Install Client" : "Installer le Client",
    "Logged in user must be a subadmin" : "L'utilisateur connecté doit être un sous-admin",
    "Password confirmation is required" : "Confirmation par mot de passe est requise",
    "Couldn't remove app." : "Impossible de supprimer l'application.",
    "Couldn't update app." : "Impossible de mettre à jour l'application",
    "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
    "Migration started …" : "Migration démarrée...",
    "Not saved" : "Non sauvegardé",
    "Sending…" : "Envoi en cours...",
    "Email sent" : "E-mail envoyé",
    "Official" : "Officielle",
    "All" : "Tous",
    "Update to %s" : "Mettre à niveau vers la version %s",
    "No apps found for your version" : "Pas d'application trouvée pour votre version",
    "The app will be downloaded from the app store" : "Cette application va être téléchargée depuis l'app store",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les applications officielles sont développées par et dans la communauté. Elles offrent les fonctionnalités indispensables et sont prêtes pour être utilisées en production.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Les applications approuvées sont créées par des développeurs de confiance et ont passé les tests de sécurité. Elles sont activement maintenues et leur code source est ouvert. Leurs développeurs les considèrent stables pour une utilisation normale.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Cette application est nouvelle ou instable, et sa sécurité n'a pas été vérifiée. Installez-la à vos risques et périls!",
    "Disabling app …" : "Désactivation de l'application...",
    "Error while disabling app" : "Erreur lors de la désactivation de l'application",
    "Disable" : "Désactiver",
    "Enable" : "Activer",
    "Enabling app …" : "Activation de l'application...",
    "Error while enabling app" : "Erreur lors de l'activation de l'application",
    "Error: This app can not be enabled because it makes the server unstable" : "Erreur : Cette application ne peut pas être activée car cela rend le serveur instable.",
    "Error: Could not disable broken app" : "Erreur : Impossible de désactiver l’application cassé",
    "Error while disabling broken app" : "Erreur lors de la désactivation de l'application cassé  .",
    "App up to date" : "Application à jour",
    "Updating …" : "Mise à jour en cours...",
    "Could not update app" : "Impossible de mettre à jour l'application",
    "Updated" : "Mise à jour terminée",
    "Removing …" : "Suppression...",
    "Could not remove app" : "Impossible de supprimer l'application.",
    "Remove" : "Supprimer",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'application a été activée mais doit être mise à jour. Vous allez être redirigé vers la page des mises à jour dans 5 secondes.",
    "App update" : "Mise à jour de l'application",
    "Approved" : "Approuvée",
    "Experimental" : "Expérimentale",
    "No apps found for {query}" : "Aucune application trouvée pour {query}",
    "Enable all" : "Tout activer",
    "Allow filesystem access" : "Autoriser l'accès au gestionnaire de fichiers",
    "Disconnect" : "Déconnexion",
    "Revoke" : "Révoquer",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome pour Android",
    "iPhone iOS" : "iPhone iOS",
    "iPad iOS" : "iPad iOS",
    "iOS Client" : "Client iOS",
    "Android Client" : "Client Android",
    "Sync client - {os}" : "Client de synchronisation - {os}",
    "This session" : "Cette session",
    "Copy" : "Copier",
    "Copied!" : "Copié !",
    "Not supported!" : "Non supporté!",
    "Press ⌘-C to copy." : "Appuyez sur ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
    "Error while loading browser sessions and device tokens" : "Erreur lors du chargement des jetons de la session du navigateur et de l'appareil",
    "Error while creating device token" : "Erreur lors de la création du jeton de l'appareil",
    "Error while deleting the token" : "Erreur lors de la suppression du jeton",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Une erreur est survenue. Veuillez fournir un certificat PEM encodé au format ASCII.",
    "Valid until {date}" : "Valide jusqu'au {date}",
    "Delete" : "Supprimer",
    "Local" : "Local",
    "Private" : "Privé",
    "Only visible to local users" : "Visible uniquement par les utilisateurs locaux",
    "Only visible to you" : "Visible uniquement par vous",
    "Contacts" : "Contacts",
    "Visible to local users and to trusted servers" : "Visible par les utilisateurs locaux et les serveurs de confiance",
    "Public" : "Publique",
    "Will be synced to a global and public address book" : "Va être synchronisé dans un carnet d'adresse global et public",
    "Verify" : "Vérifier",
    "Verifying …" : "Vérification en cours...",
    "An error occured while changing your language. Please reload the page and try again." : "Une erreur est survenue lors du changement de votre langue. Merci de recharger la page et de réessayer.",
    "Select a profile picture" : "Selectionnez une photo de profil ",
    "Very weak password" : "Mot de passe de très faible sécurité",
    "Weak password" : "Mot de passe de faible sécurité",
    "So-so password" : "Mot de passe de sécurité tout juste acceptable",
    "Good password" : "Mot de passe de sécurité suffisante",
    "Strong password" : "Mot de passe de forte sécurité",
    "Groups" : "Groupes",
    "Unable to retrieve the group list" : "Impossible de récupérer la liste du groupe",
    "Unable to delete {objName}" : "Impossible de supprimer {objName}",
    "Error creating group: {message}" : "Erreur lors de la création du groupe : {message}",
    "A valid group name must be provided" : "Vous devez indiquer un nom de groupe valide",
    "deleted {groupName}" : "{groupName} supprimé",
    "undo" : "annuler",
    "{size} used" : "{size} utilisé",
    "never" : "jamais",
    "deleted {userName}" : "{userName} supprimé",
    "No user found for <strong>{pattern}</strong>" : "Aucun utilisateur trouvé pour <strong>{pattern}</strong>",
    "Unable to add user to group {group}" : "Impossible d'ajouter l'utilisateur au groupe {group}",
    "Unable to remove user from group {group}" : "Impossible de supprimer l'utilisateur du groupe {group}",
    "Add group" : "Ajouter un groupe",
    "Invalid quota value \"{val}\"" : "Valeur de quota invalide \"{val}\"",
    "no group" : "aucun groupe",
    "Password successfully changed" : "Mot de passe changé avec succès",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "La modification du mot de passe entrainera la perte des données car la restauration de données n'est pas disponible pour cet utilisateur",
    "Could not change the users email" : "Impossible de modifier l'adresse e-mail des utilisateurs",
    "Error while changing status of {user}" : "Erreur lors du changement de statut de {user}",
    "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
    "Error creating user: {message}" : "Erreur a la création d'un utilisateur : {message}",
    "Developer documentation" : "Documentation pour développeurs",
    "View in store" : "Afficher dans le magasin d'application",
    "Limit to groups" : "Limiter aux groupes",
    "by %s" : "par %s",
    "%s-licensed" : "Sous licence %s",
    "Documentation:" : "Documentation :",
    "User documentation" : "Documentation utilisateur",
    "Admin documentation" : "Documentation administrateur",
    "Visit website" : "Visiter le site web",
    "Report a bug" : "Signaler un bogue",
    "Show description …" : "Afficher la description...",
    "Hide description …" : "Masquer la description",
    "This app has an update available." : "Cette application a une mise à jour disponible.",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Cette application n'a pas de version minimum Nextcloud exigée. Ce sera considéré comme une erreur à l'avenir.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Cette application n'a pas de version maximum Nextcloud exigée. Ce sera considéré comme une erreur à l'avenir.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Cette application ne peut être installée à cause de ces dépendances non satisfaites :",
    "Enable only for specific groups" : "Activer uniquement pour certains groupes",
    "SSL Root Certificates" : "Certificats Racines SSL",
    "Common Name" : "Nom d'usage",
    "Valid until" : "Valide jusqu'à",
    "Issued By" : "Délivré par",
    "Valid until %s" : "Valide jusqu'à %s",
    "Import root certificate" : "Importer un certificat racine",
    "Administrator documentation" : "Documentation administrateur",
    "Online documentation" : "Documentation en ligne",
    "Forum" : "Forum",
    "Getting help" : "Obtenir de l'aide",
    "Commercial support" : "Support commercial",
    "None" : "Aucun",
    "Login" : "Login",
    "Plain" : "En clair",
    "NT LAN Manager" : "Gestionnaire du réseau NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Serveur e-mail",
    "Open documentation" : "Voir la documentation",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Il est important d'indiquer un serveur afin de pouvoir envoyer des mails en cas de perte de mot de passe et pour d'autres notifications.",
    "Send mode" : "Mode d'envoi",
    "Encryption" : "Chiffrement",
    "From address" : "Adresse source",
    "mail" : "e-mail",
    "Authentication method" : "Méthode d'authentification",
    "Authentication required" : "Authentification requise",
    "Server address" : "Adresse du serveur",
    "Port" : "Port",
    "Credentials" : "Informations d'identification",
    "SMTP Username" : "Nom d'utilisateur SMTP",
    "SMTP Password" : "Mot de passe SMTP",
    "Store credentials" : "Enregistrer les identifiants",
    "Test email settings" : "Tester les paramètres e-mail",
    "Send email" : "Envoyer un e-mail",
    "Server-side encryption" : "Chiffrement côté serveur",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Le chiffrement côté serveur permet de chiffrer les fichiers qui sont téléversés sur ce serveur. Cela implique des limitations comme une performance moindre, donc activez-le seulement si nécessaire.",
    "Enable server-side encryption" : "Activer le chiffrement côté serveur",
    "Please read carefully before activating server-side encryption: " : "Veuillez lire ceci avec attention avant d'activer le chiffrement :",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Une fois le chiffrement activé, les fichiers téléversés sur le serveur à partir de ce moment seront stockés sous forme chiffrée. Il n'est possible de désactiver le chiffrement que si le module utilisé le permet spécifiquement, et que toutes les conditions préalables sont réunies pour ce faire (par exemple la création d'une clef de récupération).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Le chiffrement seul ne garantit pas la sécurité du système. Veuillez consulter la documentation pour plus d'informations à propos du fonction de l'application de chiffrement, et des cas d'utilisations supportés.",
    "Be aware that encryption always increases the file size." : "Veuillez noter que le chiffrement augmente toujours la taille des fichiers.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Il est opportun de sauvegarder régulièrement vos données. Si ces données sont chiffrées, n'oubliez pas de sauvegarder aussi les clés de chiffrement.",
    "This is the final warning: Do you really want to enable encryption?" : "Dernier avertissement : Voulez-vous vraiment activer le chiffrement ?",
    "Enable encryption" : "Activer le chiffrement",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Aucun module de chiffrement n'est chargé. Merci d'activer un module de chiffrement dans le menu des applications.",
    "Select default encryption module:" : "Sélectionnez le module de chiffrement par défaut :",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle. Veuillez activer l'application \"Default Encryption Module\" et exécuter 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle.",
    "Start migration" : "Démarrer la migration",
    "Security & setup warnings" : "Avertissements de sécurité & configuration",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Tricks section and the documentation for more information." : "Il est important pour la sécurité et la performance de votre instance que tout soit configuré correctement. Pour vous aider dans cette tâche, nous faisons des vérifications automatiques. Veuillez consulter la section Trucs et Astuces et la documentation pour plus d'informations.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ne semble pas être configuré de manière à récupérer les valeurs des variables d’environnement. Le test de la commande getenv(\"PATH\") retourne seulement une réponse vide. ",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Veuillez consulter <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">la documentation d'installation ↗</a> pour savoir comment configurer PHP sur votre serveur, en particulier en cas d'utilisation de php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuration est en mode lecture seule. Ceci empêche la modification de certaines configurations via l'interface web. De plus, le fichier doit être passé manuellement en lecture-écriture avant chaque mise à jour.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP semble configuré de manière à supprimer les blocs PHPdoc du code. Cela rendra plusieurs applications de base inaccessibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Votre base de données ne fonctionne pas avec le niveau d'isolation de transaction \"READ COMMITED\". Ceci peut causer des problèmes quand plusieurs actions sont exécutées en parallèle.",
    "%1$s below version %2$s is installed, for stability and performance reasons it is recommended to update to a newer %1$s version." : "Une version de %1$s plus ancienne que %2$s est installée. Afin d'améliorer la stabilité et les performances de votre instance Nextcloud, il est recommandé de mettre %1$s à jour.",
    "The PHP module 'fileinfo' is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir les meilleurs résultats de détection du type MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers est désactivé. Cela peut causer des conflits en cas d'accès concurrent. Configurez 'filelocking.enabled' dans config.php pour éviter ces problèmes. Consultez la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
    "System locale can not be set to a one which supports UTF-8." : "Les paramètres régionaux n'ont pu être configurés avec prise en charge d'UTF-8.",
    "This means that there might be problems with certain characters in filenames." : "Cela signifie qu'il pourrait y avoir des problèmes avec certains caractères dans les noms de fichier.",
    "It is strongly proposed to install the required packages on your system to support one of the following locales: %s." : "Il est fortement recommandé d'installer sur votre système les paquets nécessaires à la prise en charge de l'un des paramètres régionaux suivants : %s.",
    "If your installation is not installed at the root of the domain and uses system Cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si votre installation n'a pas été effectuée à la racine du domaine et qu'elle utilise le Cron du système, il peut y avoir des problèmes avec la génération d'URL. Pour les éviter, veuillez configurer l'option \"overwrite.cli.url\" de votre fichier config.php avec le chemin de la racine de votre installation (suggéré : \"%s\")",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "Merci de consulter les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">guides d'installation ↗</a> et de vérifier les erreurs ou avertissements des <a href=\"%s\">logs</a>.",
    "All checks passed." : "Tous les tests ont réussi.",
    "Background jobs" : "Tâches de fond",
    "Last job ran %s." : "Dernière tâche exécutée %s.",
    "Last job execution ran %s. Something seems wrong." : "Quelque chose s'est mal passé lors de l'exécution de la dernière tâche %s.",
    "Background job didn’t run yet!" : "La tâche de fond n'a pas encore tourné!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Afin d'optimiser au mieux la performance de votre instance, il est important de configurer correctement les travaux en arrière-plan. 'Cron' est le paramètre recommandé pour les instances de taille importante. Veuillez vous référer à la documentation Nextcloud pour plus d'informations à ce sujet.",
    "Execute one task with each page loaded" : "Exécute une tâche à chaque chargement de page",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php est enregistré à un service webcron pour exécuter cron.php toutes les 15 minutes par HTTP.",
    "Use system cron service to call the cron.php file every 15 minutes." : "Utiliser le service cron du système pour appeler le fichier cron.php toutes les 15 minutes.",
    "The cron.php needs to be executed by the system user \"%s\"." : "Le cron.php doit être exécuté par l'utilisateur système \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Pour l'exécuter, vous devez avoir l'extension PHP POSIX. Regarder la {linkstart}documentation PHP{linkend} pour plus de détails.",
    "Version" : "Version",
    "Sharing" : "Partage",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "En tant qu'administrateur, vous pouvez affiner le comportement de partage. Veuillez consulter la documentation pour plus d'informations.",
    "Allow apps to use the Share API" : "Autoriser les applications à utiliser l'API de partage",
    "Allow users to share via link" : "Autoriser les utilisateurs à partager par lien",
    "Allow public uploads" : "Autoriser les téléversements publics",
    "Always ask for a password" : "Toujours demander un mot de passe",
    "Enforce password protection" : "Imposer la protection par mot de passe",
    "Set default expiration date" : "Indiquer une date d'expiration par défaut",
    "Expire after " : "Expiration après ",
    "days" : "jours",
    "Enforce expiration date" : "Imposer la date d'expiration",
    "Allow resharing" : "Autoriser le repartage",
    "Allow sharing with groups" : "Autoriser le partage avec les groupes",
    "Restrict users to only share with users in their groups" : "N'autoriser les partages qu'entre membres de mêmes groupes",
    "Exclude groups from sharing" : "Empêcher certains groupes de partager",
    "These groups will still be able to receive shares, but not to initiate them." : "Ces groupes ne pourront plus initier de partage, mais ils pourront toujours rejoindre les partages faits par d'autres. ",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Activer l'autocomplétion des noms d'utilisateurs dans la fenêtre de partage. Si cette option est désactivée, les noms complets ou les adresses e-mail doivent être indiqués.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Afficher les conditions d'utilisation sur la page publique de téléversement (seulement lorsque la liste des fichiers est masquée).",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ce texte sera affiché sur la page publique de téléversement lorsque la liste des fichiers est masquée.",
    "Default share permissions" : "Autorisations de partage par défaut",
    "Tips & tricks" : "Trucs et astuces",
    "There are a lot of features and config switches available to optimally customize and use this instance. Here are some pointers for more information." : "Il y a beaucoup de fonctionnalités et de choix de configurations disponibles qui permettent de manière optimale de customiser et d'utiliser cette instance. Voici quelques liens pour en savoir plus.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite est actuellement utilisé comme système de gestion de base de données. Pour des installations plus volumineuses, nous vous recommandons de migrer vers un autre système de gestion de base de données.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "C'est particulièrement recommandé lorsque l'on utilise un client bureau pour la synchronisation des fichiers.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation ↗</a>." : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type' ou consultez la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation ↗</a>.",
    "How to do backups" : "Comment faire des sauvegardes",
    "Performance tuning" : "Ajustement des performances",
    "Improving the config.php" : "Amélioration du config.php ",
    "Theming" : "Personnalisation de l'apparence",
    "Check the security of your Nextcloud over our security scan" : "Vérifier la sécurité de votre Nextcloud grâce à notre scan de sécurité",
    "Hardening and security guidance" : "Guide pour le renforcement et la sécurité",
    "Personal" : "Personnel",
    "Administration" : "Administration",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Vous utilisez <strong>%s</strong> sur <strong>%s<strong>",
    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "Vous utilisez <strong>%s</strong> sur <strong>%s</strong> (<strong>%s %%</strong>)",
    "Profile picture" : "Photo de profil",
    "Upload new" : "Nouvelle depuis votre ordinateur",
    "Select from Files" : "Sélectionner depuis les Fichiers",
    "Remove image" : "Supprimer l'image",
    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 Mo",
    "Picture provided by original account" : "Photo fournie par le compte original",
    "Cancel" : "Annuler",
    "Choose as profile picture" : "Définir comme image de profil",
    "You are member of the following groups:" : "Vous êtes membre des groupes suivants :",
    "Full name" : "Nom complet",
    "No display name set" : "Aucun nom d'affichage configuré",
    "Email" : "Adresse e-mail",
    "Your email address" : "Votre adresse e-mail",
    "No email address set" : "Aucune adresse e-mail configurée",
    "For password reset and notifications" : "Pour la réinitialisation du mot de passe et les notifications",
    "Phone number" : "Numéro de téléphone",
    "Your phone number" : "Votre numéro de téléphone",
    "Address" : "Adresse",
    "Your postal address" : "Votre adresse postale",
    "Website" : "Site web",
    "It can take up to 24 hours before the account is displayed as verified." : "Cela peut prendre jusqu'à 24 heures avant que le compte soit affiché comme vérifié.",
    "Link https://…" : "Lien https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Pseudo Twitter @...",
    "Language" : "Langue",
    "Help translate" : "Aidez à traduire",
    "Password" : "Mot de passe",
    "Current password" : "Mot de passe actuel",
    "New password" : "Nouveau mot de passe",
    "Change password" : "Changer de mot de passe",
    "Web, desktop and mobile clients currently logged in to your account." : "Clients web, desktop et mobiles actuellement connectés sur votre compte.",
    "Device" : "Appareil",
    "Last activity" : "Dernière activité",
    "App name" : "Nom de l'application",
    "Create new app password" : "Créer un nouveau mot de passe d'application",
    "Use the credentials below to configure your app or device." : "Utilisez les informations d'identification ci-dessous pour configurer votre application ou appareil.",
    "For security reasons this password will only be shown once." : "Pour des raisons de sécurité, ce mot de passe ne sera affiché qu'une seule fois.",
    "Username" : "Nom d'utilisateur",
    "Done" : "Terminé",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Développé par la {communityopen}communauté Nextcloud{linkclose}, le {githubopen}code source{linkclose} est sous licence {licenseopen}AGPL{linkclose}.",
    "Follow us on Google+" : "Suivez-nous sur Google+",
    "Like our Facebook page" : "Aimez notre page Facebook",
    "Follow us on Twitter" : "Suivez-nous sur Twitter",
    "Check out our blog" : "Découvrez notre blog",
    "Subscribe to our newsletter" : "Abonnez-vous à notre lettre d'information",
    "Settings" : "Paramètres",
    "Show storage location" : "Afficher l'emplacement du stockage",
    "Show user backend" : "Montrer la source de l'identifiant",
    "Show last login" : "Montrer la dernière connexion",
    "When the password of a new user is left empty, an activation email with a link to set the password is sent." : "Quand le mot de passe d'un nouvel utilisateur est laissé vide, un mail d'activation avec un lien pour configurer le mot de passe est envoyé.",
    "Add user" : "Ajouter un utilisateur",
    "Everyone" : "Tout le monde",
    "Admins" : "Administrateurs",
    "Disabled" : "Désactivé",
    "Default quota" : "Quota par défaut",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Veuillez entrer le quota de stockage (ex. \"512 MB\" ou \"12 GB\")",
    "Unlimited" : "Illimité",
    "Other" : "Autre",
    "Group admin for" : "Administrateur de groupe pour",
    "Recovery password" : "Mot de passe de récupération ",
    "Quota" : "Quota",
    "Storage location" : "Emplacement du stockage",
    "User backend" : "Retour utilisateur",
    "Last login" : "Dernière connexion",
    "E-Mail" : "E-Mail",
    "Admin Recovery Password" : "Mot de passe Administrateur de récupération",
    "Enter the recovery password in order to recover the users files during password change" : "Entrez le mot de passe de récupération pour récupérer les fichiers utilisateurs pendant le changement de mot de passe",
    "change full name" : "Modifier le nom complet",
    "set new password" : "Changer le mot de passe",
    "change email address" : "changer l'adresse e-mail",
    "Default" : "Défaut",
    "A problem occurred, please check your log files (Error: %s)" : "Une erreur est survenue, veuillez vérifier vos fichiers de log (Erreur: %s)",
    "Migration Completed" : "Migration terminée",
    "Are you really sure you want add {domain} as trusted domain?" : "Êtes-vous vraiment sûr de vouloir ajouter {domain} comme domaine de confiance ?",
    "Add trusted domain" : "Ajouter un domaine de confiance",
    "_You have %n app update pending_::_You have %n app updates pending_" : ["Vous avez %n application en attente de mise à jour","Vous avez %n applications en attente de mise à jour"],
    "Updating...." : "Mise à jour en cours...",
    "Error while updating app" : "Erreur lors de la mise à jour de l'application",
    "Error while removing app" : "Erreur lors de la suppression de l'application",
    "A valid password must be provided" : "Un mot de passe valide doit être saisi",
    "A valid email must be provided" : "Vous devez fournir une adresse e-mail valide",
    "__language_name__" : "Français",
    "Verifying" : "Vérification en cours",
    "Personal info" : "Informations personnelles",
    "Sync clients" : "Clients de synchronisation",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Ticks section and the documentation for more information." : "Il est important pour la sécurité et la performance de votre instance que celle-ci soit correctement configurée. Afin de vous aider, votre instance effectue quelques vérifications automatiques. Veuillez consulter la section Trucs & Astuces, ainsi que la documentation, pour de plus amples informations.",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php ne semble pas être configuré de manière à récupérer les valeurs des variables d’environnement. Le test de la commande getenv(\"PATH\") retourne seulement une réponse vide. ",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Veuillez consulter <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">la documentation d'installation ↗</a> pour savoir comment configurer php sur votre serveur, en particulier en cas d'utilisation de php-fpm.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP est apparemment configuré pour supprimer les blocs de documentation internes. Cela rendra plusieurs applications de base inaccessibles.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Une version de %1$s plus ancienne que %2$s est installée. Pour améliorer la stabilité et les performances, nous vous recommandons de mettre %1$s à jour.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with MIME type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats de détection du type MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers est désactivé. Cela peut causer des conflits en cas d'accès concurrent. Activez 'filelocking.enabled' dans config.php pour éviter ces problèmes. Consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
    "This means that there might be problems with certain characters in file names." : "Cela signifie qu'il pourrait y avoir des problèmes avec certains caractères dans les noms de fichier.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nous vous recommandons d'installer sur votre système les paquets nécessaires à la prise en charge de l'un des paramètres locaux suivants : %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si votre installation n'a pas été effectuée à la racine du domaine et qu'elle utilise le cron du système, il peut y avoir des problèmes avec la génération d'URL. Pour les éviter, veuillez configurer l'option \"overwrite.cli.url\" de votre fichier config.php avec le chemin de la racine de votre installation (suggéré : \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "Merci de consulter les <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guides d'installation ↗</a> et de vérifier les erreurs ou avertissements dans les <a href=\"%s\">journaux</a>.",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php est enregistré à un service webcron pour exécuter cron.php toutes les 15 minutes par HTTP.",
    "To run this you need the PHP posix extension. See {linkstart}PHP documentation{linkend} for more details." : "Pour l'exécuter, vous devez avoir l'extension PHP posix. Regarder la {linkstart}documentation PHP{linkend} pour plus de détails.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type' ou consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>.",
    "Get the apps to sync your files" : "Obtenez les applications pour synchroniser vos fichiers",
    "Desktop client" : "Client de bureau",
    "Android app" : "Application Android",
    "iOS app" : "Application iOS",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Si vous voulez soutenir le projet {contributeopen}rejoindre son développement{linkclose} ou {contributeopen}passez le mot{linkclose}!",
    "Show First Run Wizard again" : "Ré-afficher l'assistant de premier démarrage",
    "Web, desktop, mobile clients and app specific passwords that currently have access to your account." : "Les clients web, de bureau et mobiles ainsi que les mots de passe spécifiques d'application qui ont accès actuellement à votre compte.",
    "App passwords" : "Mots de passe d'application",
    "Here you can generate individual passwords for apps so you don’t have to give out your password. You can revoke them individually too." : "Ici vous pouvez générer des mots de passe individuels pour les applications pour éviter de communiquer votre mot de passe. Vous pouvez aussi les révoquer individuellement.",
    "Follow us on Google+!" : "Suivez-nous sur Google+ !",
    "Like our facebook page!" : "Aimez notre page Facebook !",
    "Follow us on Twitter!" : "Suivez-nous sur Twitter !",
    "Check out our blog!" : "Découvrez notre blog !",
    "Subscribe to our newsletter!" : "Abonnez-vous à notre newsletter!",
    "Show email address" : "Afficher l'adresse e-mail",
    "Send email to new user" : "Envoyer un e-mail aux utilisateurs créés",
    "Create" : "Créer",
    "Group name" : "Nom du groupe"
},
"nplurals=2; plural=(n > 1);");
